summaryrefslogtreecommitdiffstats
path: root/src/gui/dialogs/qfontdialog_mac.mm
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/dialogs/qfontdialog_mac.mm')
-rw-r--r--src/gui/dialogs/qfontdialog_mac.mm10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gui/dialogs/qfontdialog_mac.mm b/src/gui/dialogs/qfontdialog_mac.mm
index f5484f0..75c37d2 100644
--- a/src/gui/dialogs/qfontdialog_mac.mm
+++ b/src/gui/dialogs/qfontdialog_mac.mm
@@ -230,7 +230,7 @@ static QFont qfontForCocoaFont(NSFont *cocoaFont, const QFont &resolveFont)
mAppModal = true;
NSWindow *ourPanel = [mStolenContentView window];
[ourPanel setReleasedWhenClosed:NO];
- [NSApp runModalForWindow:ourPanel];
+ [[NSApplication sharedApplication] runModalForWindow:ourPanel];
QAbstractEventDispatcher::instance()->interrupt();
if (mReturnCode == NSOKButton)
@@ -256,7 +256,7 @@ static QFont qfontForCocoaFont(NSFont *cocoaFont, const QFont &resolveFont)
mAppModal = false;
NSWindow *ourPanel = [mStolenContentView window];
- [NSApp beginSheet:ourPanel
+ [[NSApplication sharedApplication] beginSheet:ourPanel
modalForWindow:window
modalDelegate:0
didEndSelector:0
@@ -456,7 +456,7 @@ static QFont qfontForCocoaFont(NSFont *cocoaFont, const QFont &resolveFont)
if (mAppModal) {
mReturnCode = code;
- [NSApp stopModalWithCode:code];
+ [[NSApplication sharedApplication] stopModalWithCode:code];
} else {
if (code == NSOKButton)
mPriv->fontDialog()->accept();
@@ -636,10 +636,10 @@ void QFontDialogPrivate::mac_nativeDialogModalHelp()
// Do a queued meta-call to open the native modal dialog so it opens after the new
// event loop has started to execute (in QDialog::exec). Using a timer rather than
// a queued meta call is intentional to ensure that the call is only delivered when
// [NSApp run] runs (timers are handeled special in cocoa). If NSApp is not
// running (which is the case if e.g a top-most QEventLoop has been
// interrupted, and the second-most event loop has not yet been reactivated (regardless
- // if [NSApp run] is still on the stack)), showing a native modal dialog will fail.
+ // if [NSApplication run] is still on the stack)), showing a native modal dialog will fail.
if (nativeDialogInUse) {
Q_Q(QFontDialog);
QTimer::singleShot(1, q, SLOT(_q_macRunNativeAppModalPanel()));
@@ -636,10 +636,10 @@ void QFontDialogPrivate::mac_nativeDialogModalHelp()
// event loop has started to execute (in QDialog::exec). Using a timer rather than
// a queued meta call is intentional to ensure that the call is only delivered when
- // [NSApp run] runs (timers are handeled special in cocoa). If NSApp is not
+ // [NSApplication run] runs (timers are handeled special in cocoa). If NSApplication is not
// running (which is the case if e.g a top-most QEventLoop has been
// interrupted, and the second-most event loop has not yet been reactivated (regardless